Struct maitake_sync::wait_map::WaitOwned
source · pub struct WaitOwned<K: PartialEq, V> { /* private fields */ }Available on crate feature
alloc only.Expand description
Future returned from WaitMap::wait_owned().
This is identical to the Wait future, except that it takes an
Arc reference to the WaitMap, allowing the returned future to
live for the 'static lifetime.
This future is fused, so once it has completed, any future calls to poll
will immediately return Poll::Ready.